% tinyrox says don't edit this manually, but it can't stop you!
\name{write_namespace}
\alias{write_namespace}
\title{Write NAMESPACE File}
\usage{
write_namespace(content, path = ".", mode = "overwrite")
}
\arguments{
\item{content}{NAMESPACE content string.}

\item{path}{Package root path.}

\item{mode}{Either "overwrite" or "append".}
}
\description{
Write NAMESPACE File
}
\keyword{internal}
