% tinyrox says don't edit this manually, but it can't stop you!
\name{wrap_text}
\alias{wrap_text}
\title{Wrap Text to Width}
\usage{
wrap_text(text, width = 72)
}
\arguments{
\item{text}{Text to wrap.}

\item{width}{Maximum line width.}
}
\value{
Wrapped text with newlines.
}
\description{
Wraps text to specified width, preserving words.
}
\keyword{internal}
