% tinyrox says don't edit this manually, but it can't stop you!
\name{parse_formals_text}
\alias{parse_formals_text}
\title{Parse Formals Text}
\usage{
parse_formals_text(text)
}
\arguments{
\item{text}{Text containing function arguments.}
}
\value{
List with 'names' (argument names) and 'usage' (formatted for Rd).
}
\description{
Parse Formals Text
}
\keyword{internal}
