% tinyrox says don't edit this manually, but it can't stop you!
\docType{data}
\name{SUPPORTED_TAGS}
\alias{SUPPORTED_TAGS}
\title{All Supported Tags}
\format{
An object of class \code{character} of length 26.
}
\usage{
SUPPORTED_TAGS
}
\description{
All Supported Tags
}
\keyword{internal}
